@@ -1,45 +1,57 @@
 use pin_project::pin_project;
 #[pin(__private(project_replace = ProjOwn))]
 struct TupleStruct<T, U>(#[pin] T, U);
-#[allow(box_pointers)]
-#[allow(deprecated)]
-#[allow(explicit_outlives_requirements)]
-#[allow(single_use_lifetimes)]
-#[allow(unreachable_pub)]
-#[allow(unused_tuple_struct_fields)]
-#[allow(clippy::unknown_clippy_lints)]
-#[allow(clippy::pattern_type_mismatch)]
-#[allow(clippy::redundant_pub_crate)]
-#[allow(clippy::type_repetition_in_bounds)]
-#[allow(dead_code)]
+#[allow(
+    dead_code,
+    deprecated,
+    explicit_outlives_requirements,
+    single_use_lifetimes,
+    unreachable_pub,
+    unused_tuple_struct_fields,
+    clippy::unknown_clippy_lints,
+    clippy::absolute_paths,
+    clippy::min_ident_chars,
+    clippy::pattern_type_mismatch,
+    clippy::pub_with_shorthand,
+    clippy::redundant_pub_crate,
+    clippy::single_char_lifetime_names,
+    clippy::type_repetition_in_bounds,
+    clippy::missing_docs_in_private_items
+)]
 struct ProjOwn<T, U>(::pin_project::__private::PhantomData<T>, U);
-#[allow(box_pointers)]
-#[allow(deprecated)]
-#[allow(explicit_outlives_requirements)]
-#[allow(single_use_lifetimes)]
-#[allow(unreachable_pub)]
-#[allow(unused_tuple_struct_fields)]
-#[allow(clippy::unknown_clippy_lints)]
-#[allow(clippy::pattern_type_mismatch)]
-#[allow(clippy::redundant_pub_crate)]
-#[allow(clippy::type_repetition_in_bounds)]
-#[allow(unused_qualifications)]
-#[allow(clippy::semicolon_if_nothing_returned)]
-#[allow(clippy::use_self)]
-#[allow(clippy::used_underscore_binding)]
+#[allow(
+    unused_qualifications,
+    deprecated,
+    explicit_outlives_requirements,
+    single_use_lifetimes,
+    unreachable_pub,
+    unused_tuple_struct_fields,
+    clippy::unknown_clippy_lints,
+    clippy::absolute_paths,
+    clippy::min_ident_chars,
+    clippy::pattern_type_mismatch,
+    clippy::pub_with_shorthand,
+    clippy::redundant_pub_crate,
+    clippy::single_char_lifetime_names,
+    clippy::type_repetition_in_bounds,
+    clippy::elidable_lifetime_names,
+    clippy::missing_const_for_fn,
+    clippy::needless_lifetimes,
+    clippy::semicolon_if_nothing_returned,
+    clippy::use_self,
+    clippy::used_underscore_binding
+)]
 const _: () = {
     #[allow(unused_extern_crates)]
     extern crate pin_project as _pin_project;
-    #[allow(dead_code)]
-    #[allow(clippy::mut_mut)]
+    #[allow(dead_code, clippy::missing_docs_in_private_items, clippy::mut_mut)]
     struct __TupleStructProjection<'pin, T, U>(
         ::pin_project::__private::Pin<&'pin mut (T)>,
         &'pin mut (U),
     )
     where
         TupleStruct<T, U>: 'pin;
-    #[allow(dead_code)]
-    #[allow(clippy::ref_option_ref)]
+    #[allow(dead_code, clippy::missing_docs_in_private_items, clippy::ref_option_ref)]
     struct __TupleStructProjectionRef<'pin, T, U>(
         ::pin_project::__private::Pin<&'pin (T)>,
         &'pin (U),
@@ -61,7 +73,6 @@ const _: () = {
             }
         }
         #[allow(dead_code)]
-        #[allow(clippy::missing_const_for_fn)]
         #[inline]
         fn project_ref<'pin>(
             self: _pin_project::__private::Pin<&'pin Self>,
@@ -105,7 +116,7 @@ const _: () = {
         let _ = &this.0;
         let _ = &this.1;
     }
-    #[allow(missing_debug_implementations)]
+    #[allow(missing_debug_implementations, unnameable_types)]
     struct __TupleStruct<'pin, T, U> {
         __pin_project_use_generics: _pin_project::__private::AlwaysUnpin<
             'pin,
@@ -118,12 +129,16 @@ const _: () = {
     }
     impl<'pin, T, U> _pin_project::__private::Unpin for TupleStruct<T, U>
     where
-        __TupleStruct<'pin, T, U>: _pin_project::__private::Unpin,
+        _pin_project::__private::PinnedFieldsOf<
+            __TupleStruct<'pin, T, U>,
+        >: _pin_project::__private::Unpin,
     {}
     #[doc(hidden)]
     unsafe impl<'pin, T, U> _pin_project::UnsafeUnpin for TupleStruct<T, U>
     where
-        __TupleStruct<'pin, T, U>: _pin_project::__private::Unpin,
+        _pin_project::__private::PinnedFieldsOf<
+            __TupleStruct<'pin, T, U>,
+        >: _pin_project::__private::Unpin,
     {}
     trait TupleStructMustNotImplDrop {}
     #[allow(clippy::drop_bounds, drop_bounds)]
